@@ -197,8 +197,8 @@ class TestEncodeDecodePlain(TestCase):  # pylint: disable=too-many-public-method
         self.check_enc_dec(0.0, 5, expected_type=TYPE_FLOAT32)
 
         for type_, value, total_size in (
-                (TYPE_FLOAT32, 1.18e-38, 5),
-                (TYPE_FLOAT32, 3.4e38, 5),
+                (TYPE_FLOAT32, 1.18e-37, 5),
+                (TYPE_FLOAT32, 3.4e37, 5),
                 (TYPE_FLOAT64, 2.23e-308, 9),
                 (TYPE_FLOAT64, 12345.44e40, 9),
                 (TYPE_FLOAT64, 1.8e307, 9)):
@@ -499,12 +499,7 @@ class TestEncodeDecodeFp(TestEncodeDecodePlain):
 
     @staticmethod
     def ubjloadb(raw, *args, **kwargs):
-        try:
-            raw = BytesIO(raw)
-        except TypeError:  # pylint: disable=bare-except
-            # Invalid raw input testing
-            raise
-        return ubjload(raw, *args, **kwargs)
+        return ubjload(BytesIO(raw), *args, **kwargs)
 
     @staticmethod
     def ubjdumpb(obj, *args, **kwargs):
